@@ -10,7 +10,7 @@ import emcee
 
 class LangevinEstimation:
     '''
-    The ``Langevin_estimation`` class includes tools to estimate a polynomial Langevin equation with various
+    The ``LangevinEstimation`` class includes tools to estimate a polynomial Langevin equation with various
     drift and diffusion terms and provides the drift slope :math:`\zeta` as a resilience measure.
 
     :param data: A one dimensional numpy array containing the times series to analyse.
@@ -20,9 +20,9 @@ class LangevinEstimation:
     :param drift_model: Defines the drift model. Default is ``'3rd order polynomial'``.
                         Additionally, a ``'first order polynomial'`` can be chosen.
     :type drift_model: str
-    :param drift_model: Defines the diffusion model. Default is ``'constant'``.
+    :param diffusion_model: Defines the diffusion model. Default is ``'constant'``.
                         Additionally, a ``'first order polynomial'`` can be chosen.
-    :type drift_model: str
+    :type diffusion_model: str
     :param prior_type: Defines the used prior to calculate the posterior distribution of the data.
                         Default is ``'Non-informative linear and Gaussian Prior'``. A flat prior can be chosen
                         with ``'Flat Prior'``.
@@ -98,6 +98,8 @@ class LangevinEstimation:
 
     def __init__(self, data, time, drift_model='3rd order polynomial', diffusion_model='constant',
                  prior_type='Non-informative linear and Gaussian Prior', prior_range=None, scales=None):
+        self.drift_model = drift_model
+        self.diffusion_model = diffusion_model
         if drift_model == '3rd order polynomial':
             self.num_drift_params = 4
         elif drift_model == 'first order polynomial':
@@ -332,26 +334,30 @@ class LangevinEstimation:
         global fig, axs, sl_gr_animation, noise_gr_animation, animation_count, animation_time, animation_data  # vspan_window, noise_pdf_line, drift_slope_line, noise_line, CB_slope_I, CB_slope_II, CB_noise_I, CB_noise_II
         axs[0, 0].plot(animation_time, animation_data, color='C0')  # , color = 'b'
         axs[0, 0].set_xlim(animation_time[0], animation_time[-1])
-        axs[0, 0].axvline(crit_poi, ls=':', color='r')
+        if crit_poi != None:
+            axs[0, 0].axvline(crit_poi, ls=':', color='r')
         axs[0, 0].set_ylim(np.min(animation_data) - 1, np.max(animation_data) + 1)
         axs[0, 0].set_ylabel(r'variable $x$', fontsize=15)
         axs[0, 0].set_xlabel(r'time $t$', fontsize=15)
 
         axs[0, 1].set_xlim(noise_gr_animation[0], noise_gr_animation[-1])
         axs[0, 1].set_ylim(0, 100)
-        axs[0, 1].axvline(noi_le, ls=':', color='g')
+        if noi_le != None:
+            axs[0, 1].axvline(noi_le, ls=':', color='g')
         axs[0, 1].set_ylabel(r'Noise Posterior $P(\hat{\theta_4})$', fontsize=15)
         axs[0, 1].set_xlabel(r'noise level $\hat{\theta_4}$', fontsize=15)
 
         axs[1, 0].set_xlim(animation_time[0], animation_time[-1])
         axs[1, 0].plot(animation_time, np.zeros(animation_time.size), ls=':', color='r')
-        axs[1, 0].axvline(crit_poi, ls=':', color='r')
+        if crit_poi != None:
+            axs[1, 0].axvline(crit_poi, ls=':', color='r')
         axs[1, 0].set_ylabel(r'max posterior slope $\zeta^{\rm max}$', fontsize=15)
         axs[1, 0].set_xlabel(r'time $t$', fontsize=15)
 
         axs[1, 1].set_xlim(animation_time[0], animation_time[-1])
         axs[1, 1].set_ylim(noise_gr_animation[0], noise_gr_animation[-1])
-        axs[1, 1].plot(animation_time, noi_le * np.ones(animation_time.size), ls=':', color='g')
+        if noi_le != None:
+            axs[1, 1].plot(animation_time, noi_le * np.ones(animation_time.size), ls=':', color='g')
         axs[1, 1].set_ylabel(r'max posterior noise $\theta^{\rm max}_4$', fontsize=15)
         axs[1, 1].set_xlabel(r'time $t$', fontsize=15)
 
@@ -426,7 +432,7 @@ class LangevinEstimation:
 
     def calc_driftslope_noise(self, slope_grid, noise_grid, nwalkers=50, nsteps=10000, nburn=200,
                               n_joint_samples=50000, n_slope_samples=50000, n_noise_samples=50000,
-                              cred_percentiles=np.array([16, 1]), print_AC_tau=False,
+                              cred_percentiles=[16, 1], print_AC_tau=False,
                               ignore_AC_error=False, thinning_by=60, print_progress=False):
         '''
         Calculates the drift slope estimate :math:`\hat{\zeta}` and the noise level :math:`\hat{\sigma}`
@@ -479,7 +485,7 @@ class LangevinEstimation:
         :param print_progress: If ``True`` the progress of the MCMC sampling is shown. Default is ``False``.
         :type print_progress: bool
         '''
-
+        cred_percentiles = np.array(cred_percentiles)
         self.data_window = np.roll(self.data, shift=- self.window_shift)[:self.window_size]
         self.increments = self.data_window[1:] - self.data_window[:-1]
         self.time_window = np.roll(self.time, shift=- self.window_shift)[:self.window_size]
@@ -525,7 +531,7 @@ class LangevinEstimation:
     def perform_resilience_scan(self, window_size, window_shift, slope_grid, noise_grid,
                                              nwalkers=50, nsteps=10000, nburn=200, n_joint_samples=50000,
                                              n_slope_samples=50000, n_noise_samples=50000,
-                                             cred_percentiles=np.array([16, 1]), print_AC_tau=False,
+                                             cred_percentiles=[16, 1], print_AC_tau=False,
                                              ignore_AC_error=False, thinning_by=60, print_progress=False,
                                              slope_save_name='default_save_slopes',
                                              noise_level_save_name='default_save_noise', save=True,
@@ -622,6 +628,7 @@ class LangevinEstimation:
                         Default is ``None``.
         :type mark_noise_level: float
         '''
+        cred_percentiles = np.array(cred_percentiles)
         self.window_size = window_size
         self.window_shift = window_shift
         self.data_window = np.zeros(window_size)
